pub fn apply_parallel_web_tools(
instructions: InstructionBundle,
tool_names: impl IntoIterator<Item = impl AsRef<str>>,
) -> InstructionBundleExpand description
Append Parallel search/extract guidance when those tools are on the turn.
pub fn apply_parallel_web_tools(
instructions: InstructionBundle,
tool_names: impl IntoIterator<Item = impl AsRef<str>>,
) -> InstructionBundleAppend Parallel search/extract guidance when those tools are on the turn.