pub struct RuntimeConfig {Show 30 fields
pub default_provider: String,
pub default_model: String,
pub reasoning: Option<String>,
pub auto_compact_token_limit: Option<u32>,
pub file_backed_dynamic_context: bool,
pub hosted_web_search: HostedWebSearchConfig,
pub tool_search: ToolSearchConfig,
pub provider_tool_search: HashMap<String, ToolSearchConfigOverlay>,
pub model_tool_search: HashMap<String, ToolSearchConfigOverlay>,
pub model_edit_tools: HashMap<String, String>,
pub model_parallel_tool_calls: HashMap<String, bool>,
pub model_profiles: HashMap<String, ModelHarnessProfile>,
pub tool_allowlist: Vec<String>,
pub external_tool_timeout_seconds: u64,
pub command_shell: String,
pub workspace: Option<String>,
pub policy_mode: PolicyMode,
pub agent_swarm_mode: bool,
pub ultra_mode: bool,
pub runtime_profile: RuntimeProfile,
pub inference_router: RuntimeInferenceRouterConfig,
pub speed_policy: RuntimeSpeedPolicyConfig,
pub dynamic_workflows: RuntimeDynamicWorkflowConfig,
pub reliability: RuntimeReliabilityConfig,
pub turn_deadline_seconds: Option<u64>,
pub remote_runner_destination: Option<RunnerDestination>,
pub team_data_dir: Option<PathBuf>,
pub roadmap_data_dir: Option<PathBuf>,
pub media_generation: RuntimeMediaGenerationConfig,
pub review: RuntimeReviewConfig,
}Fields
default_provider: Stringdefault_model: Stringreasoning: Option<String>auto_compact_token_limit: Option<u32>file_backed_dynamic_context: boolhosted_web_search: HostedWebSearchConfigtool_search: ToolSearchConfigprovider_tool_search: HashMap<String, ToolSearchConfigOverlay>model_tool_search: HashMap<String, ToolSearchConfigOverlay>model_edit_tools: HashMap<String, String>model_parallel_tool_calls: HashMap<String, bool>model_profiles: HashMap<String, ModelHarnessProfile>tool_allowlist: Vec<String>external_tool_timeout_seconds: u64Seconds a host-executed external tool call may stay unresolved before it fails with a timeout error.
command_shell: Stringworkspace: Option<String>policy_mode: PolicyModeagent_swarm_mode: boolWhether agent-swarm mode is active (roadmap 104). When on, the runtime injects the swarm reminder into each turn’s developer instructions so any client benefits, not just the TUI.
ultra_mode: boolWhether ultra mode is active. When on, the runtime injects proactive multi-agent delegation policy for any model (not only Codex Sol/Terra Ultra effort). Selecting Ultra reasoning on Sol/Terra still enables proactive multi-agent for that model without requiring this flag.
runtime_profile: RuntimeProfileinference_router: RuntimeInferenceRouterConfigspeed_policy: RuntimeSpeedPolicyConfigdynamic_workflows: RuntimeDynamicWorkflowConfigreliability: RuntimeReliabilityConfigturn_deadline_seconds: Option<u64>Positive wall-clock limit for a turn in any runtime profile. None or zero is unbounded.
remote_runner_destination: Option<RunnerDestination>team_data_dir: Option<PathBuf>roadmap_data_dir: Option<PathBuf>media_generation: RuntimeMediaGenerationConfigreview: RuntimeReviewConfig[review] settings: the review sub-turn and its publishers.